@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2006-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
- * This file is part of LMMS - http://lmms.io
+ * This file is part of LMMS - https://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -34,6 +34,7 @@
 class JournallingObject;
 
 
+//! @warning many parts of this class may be rewritten soon
 class ProjectJournal
 {
 public:
@@ -45,6 +46,9 @@ public:
 	void undo();
 	void redo();
 
+	bool canUndo() const;
+	bool canRedo() const;
+
 	void addJournalCheckPoint( JournallingObject *jo );
 
 	bool isJournalling() const
@@ -73,6 +77,11 @@ public:
 		reallocID( _id, NULL );
 	}
 
+	//! hack, not used when saving a file
+	static jo_id_t idToSave( jo_id_t id );
+	//! hack, not used when loading a savefile
+	static jo_id_t idFromSave( jo_id_t id );
+
 	void clearJournal();
 	void stopAllJournalling();
 	JournallingObject * journallingObject( const jo_id_t _id )
